==> patch-2.5.5.0_3.zip: app/views/settings/blukryptSettings.php <==
<?php

use \Core\View;
use \Helpers\Url;
use Core\Language;
use Helpers\Form;
 /*
 *
 * Copyright 2015
 * ParaBlu Systems Private Limited
 * All Rights Reserved
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of ParaBlu Systems Private Limited and its suppliers, if any.
 * The intellectual and technical concepts contained herein are proprietary
 * to ParaBlu Systems Private Limited and its suppliers and may be covered by
 * Indian, US and Foreign Patents, patents in process, and are protected by
 * trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from ParaBlu Systems Private Limited.
 *
 * index.php
 *
 * @author Naveen Verma - naveenverma@parablu.com
 * @version 2.0
 * @date 12/04/19
 * @time 12:38 AM
 * 
 */
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");
?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><a href="<?=Url::basePath('settings')?>"><?=$data['title']?></a></h3></li>
                <li><a href="<?=Url::basePath('settings/office365Settings')?>"><?=$data['crumb1']?></a></li>
                <li><?=$data['crumb2']?></li>
            </ol>
        </div>
        <div class="col-lg-6 d-none">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main" ng-controller="SettingController">
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php if(!isMobile()){ View::renderTemplate('partials/sideBar', $data); }?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11">
            <span class="csrf_token d-none"><?=$data['csrf_token']?></span>
            <span class="currentPage d-none"><?='oneDriveController'?></span>
            <div class="row">
                <div class="panel col-lg-12">
                    <div class="panel-heading">
                        <h4><?=Language::show('Agent Settings', 'keywords')?></h4>
                    </div>
                    <div class="panel-body table-responsive controllerPanel" >
		       <form class="saveBlukryptSettings" ng-submit="saveBlukryptSettings()" data-parsley-validate>
			    <input type="text" class="hide" value="<?=$data["csrf_token"]?>" name="csrf_token" />
			<div class="row">
                            <div class="form-group col-lg-6">
                                <label for="host">Host</label>
                                <input type="text" class="form-control" name="host" id="host" value="<?=$data['proxy'][0]->{'host'}?>" placeholder="Enter your host" required autocomplete="off">
                                <span class="help-line text-muted d-none">Note:- Enter the complete host URL, example:- http://www.example.com</span>
                            </div>
                            <div class="form-group col-lg-6">
                                <label for="port">Port</label>
                                <input type="number" class="form-control" name="port" id="port" value="<?=$data['proxy'][0]->{'port'}?>" placeholder="Enter your Port" required autocomplete="off">
                                <span class="help-line text-muted d-none">Note:- Enter the Port number</span>
                            </div>
                            <div class="form-group col-lg-12">
                                <button style="margin-right: 5px;" type="submit" class="btn btn-success pull-right">Save</button>
			    </div>
</div>
                        </form> 
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script src="<?=Url::templatePath()?>js/angular/controllers/SettingController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>

==> patch-2.5.5.3_7_2.zip: app/views/settings/blukryptSettings.php <==
<?php

use \Core\View;
use \Helpers\Url;
use Core\Language;
use Helpers\Form;
 /*
 *
 * Copyright 2015
 * ParaBlu Systems Private Limited
 * All Rights Reserved
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of ParaBlu Systems Private Limited and its suppliers, if any.
 * The intellectual and technical concepts contained herein are proprietary
 * to ParaBlu Systems Private Limited and its suppliers and may be covered by
 * Indian, US and Foreign Patents, patents in process, and are protected by
 * trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from ParaBlu Systems Private Limited.
 *
 * index.php
 *
 * @author Naveen Verma - naveenverma@parablu.com
 * @version 2.0
 * @date 12/04/19
 * @time 12:38 AM
 * 
 */
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");
?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><a href="<?=Url::basePath('settings')?>"><?=$data['title']?></a></h3></li>
                <li><a href="<?=Url::basePath('settings/office365Settings')?>"><?=$data['crumb1']?></a></li>
                <li><?=$data['crumb2']?></li>
            </ol>
        </div>
        <div class="col-lg-6 d-none">
        </div>
    </div>
</div>
<div class="main" ng-controller="SettingController">
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php if(!isMobile()){ View::renderTemplate('partials/sideBar', $data); }?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11">
            <span class="csrf_token d-none"><?=$data['csrf_token']?></span>
            <span class="currentPage d-none"><?='oneDriveController'?></span>
            <div class="row">
                <div class="panel col-lg-12">
                    <div class="panel-heading">
                        <h4><?=Language::show('Agent Settings', 'keywords')?></h4>
                    </div>
                    <div class="panel-body table-responsive controllerPanel" >
		       <form class="saveBlukryptSettings" ng-submit="saveBlukryptSettings()" data-parsley-validate>
			    <input type="text" class="hide" value="<?=$data["csrf_token"]?>" name="csrf_token" />
			<div class="row">
                            <div class="form-group col-lg-6">
				<label for="host">Host</label>
				<?php if(!empty($data['proxy'][0]->{'host'})){ ?>
					<input type="text" class="form-control" name="host" id="host" value="<?=$data['proxy'][0]->{'host'}?>" placeholder="Enter your host" required autocomplete="off">
				<?php } else { ?>
					<input type="text" class="form-control" name="host" id="host" value="" placeholder="Enter your host" required autocomplete="off">
				<?php } ?>
                                <span class="help-line text-muted d-none">Note:- Enter the complete host URL, example:- http://www.example.com</span>
                            </div>
                            <div class="form-group col-lg-6">
				<label for="port">Port</label>
				<?php if(!empty($data['proxy'][0]->{'port'})){ ?>
					<input type="number" class="form-control" name="port" id="port" value="<?=$data['proxy'][0]->{'port'}?>" placeholder="Enter your Port" required autocomplete="off">
				<?php } else { ?>
					<input type="number" class="form-control" name="port" id="port" value="" placeholder="Enter your Port" required autocomplete="off">
				<?php } ?>
                                <span class="help-line text-muted d-none">Note:- Enter the Port number</span>
                            </div>
                            <div class="form-group col-lg-12">
                                <button style="margin-right: 5px;" type="submit" class="btn btn-success pull-right">Save</button>
			    </div>
</div>
                        </form> 
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script src="<?=Url::templatePath()?>js/angular/controllers/SettingController.js" type="text/javascript"></script>
